# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/jobs/job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/execution/v1/jobs/job.proto\x12$qwak.feature.store.execution.v1.jobs\x1a\x1fgoogle/protobuf/timestamp.proto\x1a qwak/execution/v1/backfill.proto\"\xc0\x05\n\tJobRecord\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x17\n\rlegacy_run_id\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x65xecution_id\x18\x03 \x01(\tH\x00\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x04 \x01(\t\x12\x15\n\rfeatureset_id\x18\x05 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x06 \x01(\t\x12\x12\n\naccount_id\x18\x07 \x01(\t\x12\x43\n\njob_status\x18\x08 \x01(\x0e\x32/.qwak.feature.store.execution.v1.jobs.JobStatus\x12\x31\n\rcreation_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstart_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x0cjob_metadata\x18\x0c \x01(\x0b\x32\x31.qwak.feature.store.execution.v1.jobs.JobMetadata\x12R\n\njob_labels\x18\r \x03(\x0b\x32>.qwak.feature.store.execution.v1.jobs.JobRecord.JobLabelsEntry\x12\x0c\n\x04\x63ode\x18\x0e \x01(\t\x12H\n\x04info\x18\x0f \x01(\x0b\x32\x38.qwak.feature.store.execution.v1.jobs.FailureInformationH\x01\x1a\x30\n\x0eJobLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x65xec_idB\x0e\n\x0c\x66\x61ilure_info\"\xea\x01\n\x0bJobMetadata\x12`\n\x18\x62\x61tch_ingestion_metadata\x18\x01 \x01(\x0b\x32<.qwak.feature.store.execution.v1.jobs.BatchIngestionMetadataH\x00\x12h\n!batch_backfill_ingestion_metadata\x18\x02 \x01(\x0b\x32;.qwak.feature.store.execution.v1.jobs.BatchBackfillMetadataH\x00\x42\x0f\n\rmetadata_type\"\xe7\x01\n\x16\x42\x61tchIngestionMetadata\x12<\n\x18ingested_data_start_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16ingested_data_end_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11num_affected_rows\x18\x03 \x01(\x03\x12\x38\n\x14\x62\x61tch_execution_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd6\x03\n\x15\x42\x61tchBackfillMetadata\x12\x19\n\x11num_interval_rows\x18\x01 \x01(\x03\x12\x44\n\rbackfill_spec\x18\x02 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\x12\x19\n\x11num_affected_rows\x18\x03 \x01(\x03\x12\x41\n\x1doffline_processing_start_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1boffline_processing_end_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x1conline_processing_start_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x1aonline_processing_end_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17last_batch_logical_date\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"b\n\x12\x46\x61ilureInformation\x12\x1e\n\x16original_error_message\x18\x01 \x01(\t\x12\x11\n\x07message\x18\x02 \x01(\tH\x00\x42\x19\n\x17\x66ormatted_error_message*\xac\x01\n\tJobStatus\x12\x16\n\x12JOB_STATUS_INVALID\x10\x00\x12\x18\n\x14JOB_STATUS_COMPLETED\x10\x03\x12\x15\n\x11JOB_STATUS_FAILED\x10\x04\x12\x18\n\x14JOB_STATUS_TOO_EARLY\x10\x05\x12\x1d\n\x19LEGACY_JOB_STATUS_RUNNING\x10\x06\x12\x1d\n\x19LEGACY_JOB_STATUS_PENDING\x10\x07\x42G\n*com.qwak.ai.features.execution.api.v1.jobsP\x01Z\x17qwak/fsexecution;fsjobsb\x06proto3')

_JOBSTATUS = DESCRIPTOR.enum_types_by_name['JobStatus']
JobStatus = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUS)
JOB_STATUS_INVALID = 0
JOB_STATUS_COMPLETED = 3
JOB_STATUS_FAILED = 4
JOB_STATUS_TOO_EARLY = 5
LEGACY_JOB_STATUS_RUNNING = 6
LEGACY_JOB_STATUS_PENDING = 7


_JOBRECORD = DESCRIPTOR.message_types_by_name['JobRecord']
_JOBRECORD_JOBLABELSENTRY = _JOBRECORD.nested_types_by_name['JobLabelsEntry']
_JOBMETADATA = DESCRIPTOR.message_types_by_name['JobMetadata']
_BATCHINGESTIONMETADATA = DESCRIPTOR.message_types_by_name['BatchIngestionMetadata']
_BATCHBACKFILLMETADATA = DESCRIPTOR.message_types_by_name['BatchBackfillMetadata']
_FAILUREINFORMATION = DESCRIPTOR.message_types_by_name['FailureInformation']
JobRecord = _reflection.GeneratedProtocolMessageType('JobRecord', (_message.Message,), {

  'JobLabelsEntry' : _reflection.GeneratedProtocolMessageType('JobLabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBRECORD_JOBLABELSENTRY,
    '__module__' : 'qwak.execution.v1.jobs.job_pb2'
    # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.JobRecord.JobLabelsEntry)
    })
  ,
  'DESCRIPTOR' : _JOBRECORD,
  '__module__' : 'qwak.execution.v1.jobs.job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.JobRecord)
  })
_sym_db.RegisterMessage(JobRecord)
_sym_db.RegisterMessage(JobRecord.JobLabelsEntry)

JobMetadata = _reflection.GeneratedProtocolMessageType('JobMetadata', (_message.Message,), {
  'DESCRIPTOR' : _JOBMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.JobMetadata)
  })
_sym_db.RegisterMessage(JobMetadata)

BatchIngestionMetadata = _reflection.GeneratedProtocolMessageType('BatchIngestionMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BATCHINGESTIONMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.BatchIngestionMetadata)
  })
_sym_db.RegisterMessage(BatchIngestionMetadata)

BatchBackfillMetadata = _reflection.GeneratedProtocolMessageType('BatchBackfillMetadata', (_message.Message,), {
  'DESCRIPTOR' : _BATCHBACKFILLMETADATA,
  '__module__' : 'qwak.execution.v1.jobs.job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.BatchBackfillMetadata)
  })
_sym_db.RegisterMessage(BatchBackfillMetadata)

FailureInformation = _reflection.GeneratedProtocolMessageType('FailureInformation', (_message.Message,), {
  'DESCRIPTOR' : _FAILUREINFORMATION,
  '__module__' : 'qwak.execution.v1.jobs.job_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.jobs.FailureInformation)
  })
_sym_db.RegisterMessage(FailureInformation)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.qwak.ai.features.execution.api.v1.jobsP\001Z\027qwak/fsexecution;fsjobs'
  _JOBRECORD_JOBLABELSENTRY._options = None
  _JOBRECORD_JOBLABELSENTRY._serialized_options = b'8\001'
  _JOBSTATUS._serialized_start=1893
  _JOBSTATUS._serialized_end=2065
  _JOBRECORD._serialized_start=142
  _JOBRECORD._serialized_end=846
  _JOBRECORD_JOBLABELSENTRY._serialized_start=771
  _JOBRECORD_JOBLABELSENTRY._serialized_end=819
  _JOBMETADATA._serialized_start=849
  _JOBMETADATA._serialized_end=1083
  _BATCHINGESTIONMETADATA._serialized_start=1086
  _BATCHINGESTIONMETADATA._serialized_end=1317
  _BATCHBACKFILLMETADATA._serialized_start=1320
  _BATCHBACKFILLMETADATA._serialized_end=1790
  _FAILUREINFORMATION._serialized_start=1792
  _FAILUREINFORMATION._serialized_end=1890
# @@protoc_insertion_point(module_scope)
