# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/instance_template/instance_template.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.qwak/instance_template/instance_template.proto\x12!qwak.management.instance_template\x1a/qwak/user_application/common/v0/resources.proto\"\xb0\x02\n\x14InstanceTemplateSpec\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\r\n\x05order\x18\x03 \x01(\x05\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12S\n\x15pod_compute_resources\x18\x05 \x01(\x0b\x32\x34.qwak.user_application.common.v0.PodComputeResources\x12\x46\n\rinstance_type\x18\x06 \x01(\x0e\x32/.qwak.management.instance_template.InstanceType\x12\x0b\n\x03qpu\x18\x07 \x01(\x02\x12\x15\n\raws_supported\x18\x08 \x01(\x08\x12\x15\n\rgcp_supported\x18\t \x01(\x08\"e\n\x0eInstanceFilter\x12S\n\x14instance_type_filter\x18\x01 \x01(\x0e\x32\x35.qwak.management.instance_template.InstanceTypeFilter*\x94\x01\n\x12InstanceTypeFilter\x12$\n INSTANCE_TYPE_FILTER_UNSPECIFIED\x10\x00\x12\x1c\n\x18INSTANCE_TYPE_FILTER_ALL\x10\x01\x12\x1c\n\x18INSTANCE_TYPE_FILTER_CPU\x10\x02\x12\x1c\n\x18INSTANCE_TYPE_FILTER_GPU\x10\x03*[\n\x0cInstanceType\x12\x1d\n\x19INSTANCE_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11INSTANCE_TYPE_CPU\x10\x01\x12\x15\n\x11INSTANCE_TYPE_GPU\x10\x02\x42\x30\n,com.qwak.ai.management.instance_template.apiP\x01\x62\x06proto3')

_INSTANCETYPEFILTER = DESCRIPTOR.enum_types_by_name['InstanceTypeFilter']
InstanceTypeFilter = enum_type_wrapper.EnumTypeWrapper(_INSTANCETYPEFILTER)
_INSTANCETYPE = DESCRIPTOR.enum_types_by_name['InstanceType']
InstanceType = enum_type_wrapper.EnumTypeWrapper(_INSTANCETYPE)
INSTANCE_TYPE_FILTER_UNSPECIFIED = 0
INSTANCE_TYPE_FILTER_ALL = 1
INSTANCE_TYPE_FILTER_CPU = 2
INSTANCE_TYPE_FILTER_GPU = 3
INSTANCE_TYPE_UNSPECIFIED = 0
INSTANCE_TYPE_CPU = 1
INSTANCE_TYPE_GPU = 2


_INSTANCETEMPLATESPEC = DESCRIPTOR.message_types_by_name['InstanceTemplateSpec']
_INSTANCEFILTER = DESCRIPTOR.message_types_by_name['InstanceFilter']
InstanceTemplateSpec = _reflection.GeneratedProtocolMessageType('InstanceTemplateSpec', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCETEMPLATESPEC,
  '__module__' : 'qwak.instance_template.instance_template_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.InstanceTemplateSpec)
  })
_sym_db.RegisterMessage(InstanceTemplateSpec)

InstanceFilter = _reflection.GeneratedProtocolMessageType('InstanceFilter', (_message.Message,), {
  'DESCRIPTOR' : _INSTANCEFILTER,
  '__module__' : 'qwak.instance_template.instance_template_pb2'
  # @@protoc_insertion_point(class_scope:qwak.management.instance_template.InstanceFilter)
  })
_sym_db.RegisterMessage(InstanceFilter)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,com.qwak.ai.management.instance_template.apiP\001'
  _INSTANCETYPEFILTER._serialized_start=545
  _INSTANCETYPEFILTER._serialized_end=693
  _INSTANCETYPE._serialized_start=695
  _INSTANCETYPE._serialized_end=786
  _INSTANCETEMPLATESPEC._serialized_start=135
  _INSTANCETEMPLATESPEC._serialized_end=439
  _INSTANCEFILTER._serialized_start=441
  _INSTANCEFILTER._serialized_end=542
# @@protoc_insertion_point(module_scope)
