# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.ecosystem.v0 import ecosystem_runtime_service_pb2 as qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2


class QwakEcosystemRuntimeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Authenticate = channel.unary_unary(
                '/qwak.ecosystem.v0.QwakEcosystemRuntime/Authenticate',
                request_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.AuthenticateRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.AuthenticateResponse.FromString,
                )
        self.GetAuthenticatedUserContext = channel.unary_unary(
                '/qwak.ecosystem.v0.QwakEcosystemRuntime/GetAuthenticatedUserContext',
                request_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAuthenticatedUserContextRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAuthenticatedUserContextResponse.FromString,
                )
        self.ListUserAccounts = channel.unary_unary(
                '/qwak.ecosystem.v0.QwakEcosystemRuntime/ListUserAccounts',
                request_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.ListUserAccountsRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.ListUserAccountsResponse.FromString,
                )
        self.GetAccount = channel.unary_unary(
                '/qwak.ecosystem.v0.QwakEcosystemRuntime/GetAccount',
                request_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAccountResponse.FromString,
                )
        self.GetCloudCredentials = channel.unary_unary(
                '/qwak.ecosystem.v0.QwakEcosystemRuntime/GetCloudCredentials',
                request_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetCloudCredentialsRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetCloudCredentialsResponse.FromString,
                )
        self.GetUnifiedUserContext = channel.unary_unary(
                '/qwak.ecosystem.v0.QwakEcosystemRuntime/GetUnifiedUserContext',
                request_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetUnifiedUserContextRequest.SerializeToString,
                response_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetUnifiedUserContextResponse.FromString,
                )


class QwakEcosystemRuntimeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Authenticate(self, request, context):
        """Authenticate user and get token
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthenticatedUserContext(self, request, context):
        """List accounts of the user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserAccounts(self, request, context):
        """List the accounts of the login user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """Get account by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCloudCredentials(self, request, context):
        """Get cloud credentials
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUnifiedUserContext(self, request, context):
        """Get a user context for a given user (from all kinds) and a given account
        That method is for internal use to get information by the services, and not for the end user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QwakEcosystemRuntimeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Authenticate': grpc.unary_unary_rpc_method_handler(
                    servicer.Authenticate,
                    request_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.AuthenticateRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.AuthenticateResponse.SerializeToString,
            ),
            'GetAuthenticatedUserContext': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthenticatedUserContext,
                    request_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAuthenticatedUserContextRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAuthenticatedUserContextResponse.SerializeToString,
            ),
            'ListUserAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserAccounts,
                    request_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.ListUserAccountsRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.ListUserAccountsResponse.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAccountRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAccountResponse.SerializeToString,
            ),
            'GetCloudCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCloudCredentials,
                    request_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetCloudCredentialsRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetCloudCredentialsResponse.SerializeToString,
            ),
            'GetUnifiedUserContext': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUnifiedUserContext,
                    request_deserializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetUnifiedUserContextRequest.FromString,
                    response_serializer=qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetUnifiedUserContextResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.ecosystem.v0.QwakEcosystemRuntime', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class QwakEcosystemRuntime(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Authenticate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.v0.QwakEcosystemRuntime/Authenticate',
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.AuthenticateRequest.SerializeToString,
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.AuthenticateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthenticatedUserContext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.v0.QwakEcosystemRuntime/GetAuthenticatedUserContext',
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAuthenticatedUserContextRequest.SerializeToString,
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAuthenticatedUserContextResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.v0.QwakEcosystemRuntime/ListUserAccounts',
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.ListUserAccountsRequest.SerializeToString,
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.ListUserAccountsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.v0.QwakEcosystemRuntime/GetAccount',
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAccountRequest.SerializeToString,
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCloudCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.v0.QwakEcosystemRuntime/GetCloudCredentials',
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetCloudCredentialsRequest.SerializeToString,
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetCloudCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUnifiedUserContext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.ecosystem.v0.QwakEcosystemRuntime/GetUnifiedUserContext',
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetUnifiedUserContextRequest.SerializeToString,
            qwak_dot_ecosystem_dot_v0_dot_ecosystem__runtime__service__pb2.GetUnifiedUserContextResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
